********************************************************************************
*                                                                              *
*                 SPSS Program to Score the ePIRLS 2016 Items                  *
*                            PIRLS 2016 User Guide                             *
*                                                                              *
********************************************************************************.

SET MPRINT=ON .

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

  * Code for multiple-choice items .

  !IF (!UPCASE(!TYPE)=MC) !THEN
     !DO !I !IN (!ITEM) .
        RECODE !I (!RIGHT = 1      ) /* Item Key         */
                  (!NR    = 0      ) /* Not Reached      */
                  (!NA    = SYSMIS ) /* Not Administered */
                  (!OM    = 0      ) /* Omitted          */
                  (!OTHER = 0      ) /* Other Missing    */
                  (ELSE   = 0      ) .
     !DOEND .
  !IFEND .

  * Code for constructed-response items .

  !IF (!UPCASE(!TYPE)=CR) !THEN
     !DO !I !IN (!ITEM) .
        RECODE !I (3      = 3      ) /* 3 Points         */
                  (2      = 2      ) /* 2 Points         */
                  (1      = 1      ) /* 1 Point          */
                  (0      = 0      ) /* 0 Points         */
                  (!NR    = 0      ) /* Not Reached      */
                  (!NA    = SYSMIS ) /* Not Administered */
                  (!OM    = 0      ) /* Omitted          */
                  (!OTHER = 0      ) /* Other Missing    */
                  (ELSE   = 0      ) .
     !DOEND .
  !IFEND .

!ENDDEFINE .

DEFINE DOIT (INDIR  = !CHAREND('/') /
             OUTDIR = !CHAREND('/') /
             INFILE = !CHAREND('/') ) .

  * Get the student achievement data .

  GET FILE = !QUOTE(!CONCAT(!INDIR,'\',!INFILE,'.SAV')) .

  * Score multiple-choice items with A key .

  SCOREIT TYPE = MC / ITEM = E11M05M   E11R12M   E11T07M   E11T12M   E11Z07M
                             E11Z20MB  E11Z20MD  /
          RIGHT = 1 / NR =  6 / NA = SYSMIS / OM =  9 / OTHER =  7 .
  SCOREIT TYPE = MC / ITEM = E11M16MC  E11R07MC  /
          RIGHT = 1 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 97 .

  * Score multiple-choice items with B key .

  SCOREIT TYPE = MC / ITEM = E11B01M   E11B02M   E11M12M   E11R04M   E11R10M
                             E11R13M   E11T01M   E11T13M   E11Z01M   E11Z11M
                             E11Z15M   E11Z20MC  /
          RIGHT = 2 / NR =  6 / NA = SYSMIS / OM =  9 / OTHER =  7 .
  SCOREIT TYPE = MC / ITEM = E11R03MD  E11R07MD  /
          RIGHT = 2 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 97 .

  * Score multiple-choice items with C key .

  SCOREIT TYPE = MC / ITEM = E11B07M   E11B11M   E11M01M   E11M07M   E11M10M
                             E11M19M   E11R01M   E11T03M   E11T16M   E11Z05M
                             E11Z08M   E11Z18M   E11Z20MA  /
          RIGHT = 3 / NR =  6 / NA = SYSMIS / OM =  9 / OTHER =  7 .
  SCOREIT TYPE = MC / ITEM = E11M16MB  E11R03MC  E11R07MA  /
          RIGHT = 3 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 97 .

  * Score multiple-choice items with D key .

  SCOREIT TYPE = MC / ITEM = E11B05M   E11M06M   E11T04M   E11T11M   E11T15M
                             E11Z03M   E11Z10M   E11Z13M /
          RIGHT = 4 / NR =  6 / NA = SYSMIS / OM =  9 / OTHER =  7 .
  SCOREIT TYPE = MC / ITEM = E11R03MA  E11R07MB  /
          RIGHT = 4 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 97 .

  * Score multiple-choice items with E key .

  SCOREIT TYPE = MC / ITEM = E11M16MD  /
          RIGHT = 5 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 97 .

  * Score multiple-choice items with F key .

  SCOREIT TYPE = MC / ITEM = E11M16MA  E11R03MB  /
          RIGHT = 6 / NR = 96 / NA = SYSMIS / OM = 99 / OTHER = 97 .

  * Score Constructed-Response Items .

  SCOREIT TYPE = CR / ITEM = E11B03C   E11B04C   E11B06C   E11B08C   E11B09C
                             E11B10C   E11B12C   E11B13C   E11B14C   E11B15C
                             E11B16C   E11B17C   E11M02C   E11M03C   E11M04C
                             E11M08C   E11M09C   E11M11C   E11M13C   E11M14C
                             E11M15C   E11M16C   E11M17C   E11M18C   E11M20C
                             E11R02C   E11R03C   E11R05C   E11R06C   E11R07C
                             E11R08C   E11R09C   E11R11C   E11R14C   E11R15C
                             E11R16C   E11T02C   E11T05C   E11T06C   E11T08C
                             E11T09C   E11T10C   E11T14C   E11T17C   E11T18C
                             E11T18CA  E11T18CB  E11T18CD  E11Z02C   E11Z04C
                             E11Z06C   E11Z09C   E11Z12C   E11Z14C   E11Z16C
                             E11Z17C   E11Z19C   E11Z20C   /
          RIGHT = 0 / NR =  6 / NA = SYSMIS / OM =  9 / OTHER =  7 .

  EXECUTE .

  * Save the student data .

  SAVE OUTFILE = !QUOTE(!CONCAT(!OUTDIR,'\',!INFILE,'_SCR.SAV')) .

  NEW FILE .

!ENDDEFINE .

DOIT INDIR  = <Specify location of input SPSS data file using format "x:\xxx"> /
     OUTDIR = <Specify location of output SPSS data file using format "x:\xxx"> /
     INFILE = <Specify name of merged SPSS student achievement data file> .
